| bgev2gev | R Documentation |
Conversion between location, scale and shape parameters of the generalised extreme value distribution and corresponding parameters of blended generalised extreme value distribution in both directions.
bgev2gev(
location,
scale,
shape,
pa = 0.05,
pb = 0.2,
alpha = 0.5,
beta = 0.5,
simplify = FALSE
)
gev2bgev(
location,
scale,
shape,
pa = 0.05,
pb = 0.2,
alpha = 0.5,
beta = 0.5,
simplify = FALSE
)
location, scale, shape |
location, scale and shape parameters. |
pa, pb, alpha, beta |
Gumbel to GEV mixing parameters; see Details. |
simplify |
logical; should |
The blended generalised extreme value distribution has location
parameter q_\alpha, scale s_\beta and
shape \xi parameters; see, e.g., dbgev. The generalised
extreme value distribution's location and scale parameters in its typical
form are given by \mu = q_\alpha - s_\beta (\ell_{\alpha, \xi} - 1) / (\ell_{1 - \beta/2, \xi} - \ell_{\beta/2, \xi})
and \sigma = \xi s_\beta / (\ell_{1 - \beta/2, \xi} - \ell_{\beta/2, \xi}).
So bgev2gev gives the mapping (q_\alpha, s_\beta, \xi) \mapsto (\mu, \sigma, \xi)).
The reverse mapping, (\mu, \sigma, \xi) \mapsto (q_\alpha, s_\beta, \xi)),
is given by gev2bgev.
A list or array if simplify = TRUE.
Castro-Camilo, D., Huser, R., & Rue, H. (2022). Practical strategies for generalized extreme value-based regression models for extremes. Environmetrics, 33(6), e2742. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/env.2742")}
dbgev
bgev2gev(2, 1, .1)
gev2bgev(2, 1, .1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.