| family.evgam | R Documentation |
Various distributions can be fitted with function evgam using
family = "...", where options for ... are given below. The default is
family = "gev".
The following families are currently available using evgam(..., family = "...").
"ald", the asymmetric Laplace distribution. This is primarily
intended for quantile regression, as in Yu & Moyeed (2001);
"gev" (default), the generalised extreme value (GEV) distribution;
"exp", the exponential distribution;
"gpd", the generalised Pareto distribution;
"gauss", the Gaussian distribution.
"pp", the point process model for extremes. This is implemented
through r-largest order statistics. See Details below.
"weibull", the Weibull distribution;
"exi", estimation if the extremal index. See Schlather & Tawn (2003) and Details below.
"egpd", the extended generalised Pareto distribution. See Naveau
et al. (2016) and Details below;
"bgev", the blended GEV distribution. See Castro-Camilo et al (2022) and Details
"condex", the conditional extreme value model. See Details
"custom", custom distributions. See custom.evgam for an example of use.
Arguments for the asymmetric Laplace distribution are given by ald.args. A
scalar tau defines the quantile sought, which has no default. The scalar
C specifies the curvature parameter of Oh et al. (2011).
Arguments for extremal index estimation are given by exi.args. A character
string id specifies the variable in dataover which an nexi
(default 2) running max. has been taken. The link is specified as a character string,
which is one of "logistic", "probit", "cloglog"; defaults to "logistic".
Arguments for the point process model are given by pp.args. An integer r
specifies the number of order statistics from which the model will be estimated.
If r = -1, all data will be used. The character string id specifies the variable
in data over which the point process isn't integrated; e.g. if a map
of parameter estimates related to extremes over time is sought, integration isn't
over locations. The scalar nper number of data per period of interest; scalar or
integer vector ny specifies the number of periods; if length(ny) > 1
then names(ny) must ne supplied and must match to every unique id.
logical correctny specifies whether ny is
corrected to adjust proportionally for data missingness.
Arguments for the point process model are given by bgev.args. Probabilities
pa and pb specify the lower and upper probabilities at the which
the Gumbel distribution blends into a GEV distribution. Then alpha and
beta specify the quantile and its range, respectively, used to parameterise
the GEV distribution. Defaults are pa = 0.05 and pb = 0.2 and
alpha = beta = 0.5, as used in Castro-Camilo et al (2022).
Arguments for extended Pareto distribution are given by egpd.args. An
integer, model, specifies which model from Naveau et at. (2016) to fit.
The first two parameters of each are the GPD's log scale and shape parameters,
(\log \psi, \xi). Then, in the notation of Naveau et at. (2016) the
remaining parameters are (\log \kappa),
(\log \kappa_1, \log \kappa_2, \textrm{logit}(p)),
(\log \delta) and (\log \delta, \log \kappa) for models i, ii, iii
and iv, respectively, which are specified with model = 1, 2, 3 or
4, respectively.
See evgam for examples.
Castro-Camilo, D., Huser, R., & Rue, H. (2022). Practical strategies for generalized extreme value-based regression models for extremes. Environmetrics, 33(6), e2742. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/env.2742")}
Naveau, P., Huser, R., Ribereau, P., and Hannart, A. (2016), Modeling jointly low, moderate, and heavy rainfall intensities without a threshold selection, Water Resources Research, 52, 2753-2769. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/2015WR018552")}
Oh, H. S., Lee, T. C., & Nychka, D. W. (2011). Fast nonparametric quantile regression with arbitrary smoothing methods. Journal of Computational and Graphical Statistics, 20(2), 510-526. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jcgs.2010.10063")}
Schlather, M., & Tawn, J. A. (2003). A dependence measure for multivariate and spatial extreme values: Properties and inference. Biometrika, 90(1), 139-156. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/biomet/90.1.139")}
Youngman, B. D. (2022). evgam: An R Package for Generalized Additive Extreme Value Models. Journal of Statistical Software. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v103.i03")}
Yu, K., & Moyeed, R. A. (2001). Bayesian quantile regression. Statistics & Probability Letters, 54(4), 437-447.\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/S0167-7152(01)00124-9")}
evgam
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.