| laplace | R Documentation |
Density, distribution function, quantile function and random generation for
the Laplace distribution with location location and scale scale.
dlaplace(x, location = 0, scale = 1, log = FALSE)
plaplace(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qlaplace(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rlaplace(n, location = 0, scale = 1)
x, q |
vector of quantiles. |
location |
location parameter (mean). |
scale |
scale parameter (must be positive). |
log, log.p |
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are P[X <= x], otherwise, P[X > x]. |
p |
vector of probabilities. |
n |
number of observations. |
dlaplace gives the density,
plaplace gives the distribution function,
qlaplace gives the quantile function, and
rlaplace generates random deviates.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.