Density, distribution function, quantile function and random generation for
the Laplace distribution with location location and scale scale.
dlaplace(x, location = 0, scale = 1, log = FALSE)plaplace(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qlaplace(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rlaplace(n, location = 0, scale = 1)
dlaplace gives the density,
plaplace gives the distribution function,
qlaplace gives the quantile function, and
rlaplace generates random deviates.
vector of quantiles.
location parameter (mean).
scale parameter (must be positive).
logical; if TRUE, probabilities p are given as log(p).
logical; if TRUE (default), probabilities are P[X <= x], otherwise, P[X > x].
vector of probabilities.
number of observations.