| qev | R Documentation |
Quantile estimation of a composite extreme value distribution
qev(
p,
loc,
scale,
shape,
m = 1,
alpha = 1,
theta = 1,
family,
tau = 0,
bgev.args = list(pa = 0.05, pb = 0.2, alpha = 0.5, beta = 0.5),
start = NULL,
method = "uniroot"
)
p |
a scalar giving the quantile of the distribution sought |
loc |
a scalar, vector or matrix giving the location parameter |
scale |
as above, but scale parameter |
shape |
as above, but shape parameter |
m |
a scalar giving the number of values per return period unit, e.g. 365 for daily data giving annual return levels |
alpha |
a scalar, vector or matrix of weights if within-block variables not identically distributed and of different frequencies |
theta |
a scalar, vector or matrix of extremal index values |
family |
a character string giving the family for which return levels sought |
tau |
a scalar, vector or matrix of values giving the threshold quantile for the GPD (i.e. 1 - probability of exceedance) |
bgev.args |
a list specifying parameters of the blended GEV distribution; see Details |
start |
a 2-vector giving starting values that bound the return level |
method |
a character string giving the numerical estimation procedure; defaults to |
If F is the generalised extreme value, generalised Pareto or blended
GEV distribution, qev solves
\prod_{j=1}^n \big\{F_i(z)\}^{m \alpha_j \theta_j} = p.
for i = 1, \ldots, k. So vectors are supplied as $n$-vectors and matrices
are supplied as n \times k matrices.
For all distributions, location, scale and shape parameters are given by
loc, scale and shape. The generalised Pareto
distribution, for \xi \neq 0 and z > u, is parameterised as
1 - (1 - \tau) [1 + \xi (z - u) / \psi_u]^{-1/\xi},
where u, \psi_u and \xi are its location, scale and shape
parameters, respectively, and \tau corresponds to argument tau.
For the blended GEV distribution pa, pb, alpha and
beta specify additional parameters of the blended GEV distribution; see
family.evgam for details.
Estimates either use function uniroot or method = "newton" uses
the Newton-Rhaphson method. The latter is often much quicker if matrices
are supplied, i.e. for k > 1.
A scalar or vector of estimates of p
qev(0.9, c(1, 2), c(1, 1.1), .1, family = "gev")
qev(0.99, c(1, 2), c(1, 1.1), .1, family = "gpd", tau = 0.9)
# an example representative on monthly estimates at two locations
qev(0.9, matrix(c(1:12, 2:13), 12, 2), 1.1, .1, family = "gev")
# a blended GEV example with default blended GEV specification
qev(0.9, matrix(c(1:12, 2:13), 12, 2), 1.1, .1, family = "bgev")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.